==> rgmining-ria-0.9.4.tar.gz: rgmining-ria-0.9.4/README.md <==
# Repeated Improvement Analysis
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![Build Status](https://travis-ci.org/rgmining/ria.svg?branch=master)](https://travis-ci.org/rgmining/ria)
[![wercker status](https://app.wercker.com/status/7751cf9d910a68b30ab010c5c341eb59/s/master "wercker status")](https://app.wercker.com/project/byKey/7751cf9d910a68b30ab010c5c341eb59)
[![Code Climate](https://codeclimate.com/github/rgmining/ria/badges/gpa.svg)](https://codeclimate.com/github/rgmining/ria)
[![Release](https://img.shields.io/badge/release-0.9.3-brightgreen.svg)](https://github.com/rgmining/ria/releases/tag/v0.9.3)

[![Logo](https://rgmining.github.io/ria/_static/image.png)](https://rgmining.github.io/ria/)

This package provides 4 algorithms for review graph mining project.
[Mutually Reinforcing Analysis (MRA)](http://www.anrdoezrs.net/links/8186671/type/dlg/http://link.springer.com/chapter/10.1007%2F978-3-642-23088-2_25)
algorithm is an algorithm we've introduced in DEXA 2011,
[Repeated Improvement Analysis (RIA)](http://db-event.jpn.org/deim2015/paper/253.pdf) algorithm
is an algorithm we've introduced in DEIM 2015.
Algorithm **One** has been proposed by Ee-Peng Lim *ea al.* in CIKM 2010, and algorithm **OneSum** is an variation of it made by us.

This package is a part of [Review Graph Mining Project](https://rgmining.github.io/)
which provides other algorithms, datasets, and helper libraries.

See [the documents](https://rgmining.github.io/ria/) for more information.


## Installation
Use `pip` to install this package.

```
pip install --upgrade rgmining-ria
```

## License
This software is released under The GNU General Public License Version 3,
see [COPYING](https://github.com/rgmining/ria/blob/master/COPYING) for more detail.

==> rgmining-ria-0.9.5.tar.gz: rgmining-ria-0.9.5/README.md <==
# Repeated Improvement Analysis
[![GPLv3](https://img.shields.io/badge/license-GPLv3-blue.svg)](https://www.gnu.org/copyleft/gpl.html)
[![Build Status](https://travis-ci.org/rgmining/ria.svg?branch=master)](https://travis-ci.org/rgmining/ria)
[![wercker status](https://app.wercker.com/status/7751cf9d910a68b30ab010c5c341eb59/s/master "wercker status")](https://app.wercker.com/project/byKey/7751cf9d910a68b30ab010c5c341eb59)
[![Code Climate](https://codeclimate.com/github/rgmining/ria/badges/gpa.svg)](https://codeclimate.com/github/rgmining/ria)
[![Release](https://img.shields.io/badge/release-0.9.5-brightgreen.svg)](https://github.com/rgmining/ria/releases/tag/v0.9.5)

[![Logo](https://rgmining.github.io/ria/_static/image.png)](https://rgmining.github.io/ria/)

This package provides 4 algorithms for review graph mining project.
[Mutually Reinforcing Analysis (MRA)](http://www.anrdoezrs.net/links/8186671/type/dlg/http://link.springer.com/chapter/10.1007%2F978-3-642-23088-2_25)
algorithm is an algorithm we've introduced in DEXA 2011,
[Repeated Improvement Analysis (RIA)](http://db-event.jpn.org/deim2015/paper/253.pdf) algorithm
is an algorithm we've introduced in DEIM 2015.
Algorithm **One** has been proposed by Ee-Peng Lim *ea al.* in CIKM 2010, and algorithm **OneSum** is an variation of it made by us.

This package is a part of [Review Graph Mining Project](https://rgmining.github.io/)
which provides other algorithms, datasets, and helper libraries.

See [the documents](https://rgmining.github.io/ria/) for more information.


## Installation
Use `pip` to install this package.

```shell
$ pip install --upgrade rgmining-ria
```

## License
This software is released under The GNU General Public License Version 3,
see [COPYING](https://github.com/rgmining/ria/blob/master/COPYING) for more detail.
